### Name: pcpattL
### Title: Likert to Paired Comparison Patterns - Design Matrix
### Aliases: pcpattL
### Keywords: misc

### ** Examples

## Not run: 
##D 
##D ## EXAMPLE 1: TYPICAL USAGE
##D ## not run because input data file does not exist
##D 
##D # defining the ctrl list
##D # would be typically read from file using source()
##D 
##D testex1<-list(
##D    datafile     = "test/test.dat",
##D    nitems       = 5,
##D    blnRevert    = FALSE,
##D    blnIntcovs   = FALSE,
##D 
##D    cov.sel      = c("SEX","URB"),
##D 
##D    blnGLIMcmds  = TRUE,
##D    glimCmdFile  = "test/test.gli",
##D    outFile      = "test/test.design",
##D    intFile      = ""        # since blnIntcovs = FALSE
##D )
##D 
##D # call
##D 
##D pcpattL(testex1)
##D 
## End(Not run)

## EXAMPLE 2: WITH LOADED DATAFRAME

data(xmpl)   # example data in package

testex2<-list(
   datafile     = "",       # dataframe used
   nitems       = 3,
   blnRevert    = FALSE,
   blnIntcovs   = TRUE,

   cov.sel      = "ALL",

   blnGLIMcmds  = FALSE,    # no GLIM output
   glimCmdFile  = "",
   outFile      = "",
   intFile      = ""
)

dsgnmat <- pcpattL(testex2, xmpl)

print(head(dsgnmat))

## EXAMPLE 3: ILLUSTRATING THE ISSP2000 EXAMPLE
##   simplified version of the analysis as
##   given in Dittrich et.al.(2007)

data(issp2000)

testex3<-list(
   datafile     = "",
   nitems       = 6,
   blnRevert    = FALSE,
   blnIntcovs   = FALSE,

   cov.sel      = c("SEX","EDU"),

   blnGLIMcmds  = FALSE,
   glimCmdFile  = "",
   outFile      = "",
   intFile      = ""
)

design <- pcpattL(testex3, issp2000)

#  - fit null multinomial model (basic model for items without
#    subject covariates) through Poisson distribution.
#  - SEX:EDU parameters are nuisance parameters
#  - the last item (GENE) becomes a reference item
#    in the model and is aliased; all other items
#    are compared to this last item

# item parameters with undecided effects and no covariate effects.

summary(glm(y~SEX:EDU + CAR+IND+FARM+WATER+TEMP+GENE
                + U12+U13+U23+U14+U24+U34+U15+U25+U35+U45+U16+U26+U36+U46+U56,
             family=poisson, data=design))

# now add main effect of SEX on items

summary(glm(y~SEX:EDU + CAR+IND+FARM+WATER+TEMP+GENE
                + (CAR+IND+FARM+WATER+TEMP+GENE):SEX
                + U12+U13+U23+U14+U24+U34+U15+U25+U35+U45+U16+U26+U36+U46+U56,
             family=poisson, data=design))

## Don't show: 
   testex2$cov.sel<-""
   dsgn2<-pcpattL(testex2, xmpl)
   print(head(dsgn2))
## End Don't show




