`init` <-
function(dfr){
################################################################
# initialisations, read data
################################################################


    datafile  <-get("datafile",get("ENV",environment(pcpattL)))
    nitems    <-get("nitems",get("ENV",environment(pcpattL)))
    cov.sel   <-get("cov.sel",get("ENV",environment(pcpattL)))
    blnRevert <-get("blnRevert",get("ENV",environment(pcpattL)))

    if (is.null(dfr)) {
        if(file.access(datafile, mode=0) == 0){
           dat<-as.matrix(read.table(datafile,header=TRUE))  # datafile
        } else {
           stop("\ninput data file does not exist!\n")
        }
    } else {
        dat<-as.matrix(dfr)                                  # dataframe
        dat<-apply(dat,2,as.numeric)
    }
    NAs<-which(!complete.cases(dat))                  # check for NA
    if (length(NAs)>0){
        cat("\tNAs in lines",NAs," - removed from data\n")
        notNAs<-which(complete.cases(dat))
        dat<-dat[notNAs,]
    }

    nsubj<-nrow(dat)
    ncolumns<-ncol(dat)
    nobj<-nitems
    ncov<-ncolumns - nitems

    objnames<-colnames(dat)[1:nobj]
    ncatL<-diff(range(dat[,1:nobj])) + 1   # number of rating(Likert) categories

    ncomp<-nobj*(nobj-1)/2                 # number of comparisons
                                           # number of different resp patterns
        npatt<-ncatL**nobj                 #    for ratings/likert
        ncatPC<-ncatL*2-1                  #    number of categories for differences



    blnSubjcov<-cov.sel[1]!=""             #    FALSE if ""

    if (blnSubjcov) {
       inpcovnames <- colnames(dat)[(nobj+1):ncolumns]
       if (toupper(cov.sel[1]) == "ALL"){   # all covariates included
          cov.sel <- inpcovnames
       } else if(length(setdiff(cov.sel,inpcovnames))>0) {
           stop("\ncovariate name(s) in cov.sel incorrectly specified\n")
       }
       cov.case<-as.matrix(dat[,c(cov.sel)])
       colnames(cov.case)<-cov.sel
       covlevels<-apply(cov.case,2,max)
       ncov<-length(cov.sel)
    } else {
       cov.case=NULL
       covlevels=NULL
       covnames=NULL
       ncov<-0
    }

    reverse<-ifelse(blnRevert,-1,1)

    ret<-list(dat=dat,
         nsubj=nsubj,
         nobj=nobj,
         ncatL=ncatL,
         reverse=reverse,
         objnames=objnames,
         npatt=npatt,
         ncomp=ncomp,
         blnSubjcov=blnSubjcov,
         ncov=ncov,
         covlevels=covlevels,
         covnames=cov.sel,
         cov.case=cov.case,
         nintcovs.out=40
         )
    # writes all control structures to environment ENV
    for (i in 1:length(ret))
      do.call("assign", list(names(ret)[i],ret[[i]],get("ENV",environment(pcpattL)) ))

}

